@@ -54,7 +54,7 @@ from symupy.utils import SimulatorRequest, Configurator
 from symupy.logic import RuntimeDevice
 
 from symupy.utils import timer_func, printer_time
-from symupy.utils import constants as ct
+from symupy.utils import constants as CT
 
 from symupy.components import V2INetwork, V2VNetwork
 from symupy.components import Vehicle
@@ -114,7 +114,7 @@ class Simulator(Configurator, RuntimeDevice):
     def __init__(
         self,
         libraryPath: str = "",
-        bufferSize: int = ct.BUFFER_STRING,
+        bufferSize: int = CT.BUFFER_STRING,
         writeXML: bool = True,
         traceFlow: bool = False,
         totalSteps: int = 0,
@@ -136,11 +136,19 @@ class Simulator(Configurator, RuntimeDevice):
         return f"{self.__class__.__name__}({self.libraryPath})"
 
     # ============================================================================
-    # CLASS AND DEFINITIONS
+    # LOADING METHODS
     # ============================================================================
 
     def load_symuvia(self) -> None:
-        """ load SymuVia shared library """
+        """
+            This is a method to load the shared symuvia library into python. This method
+            is used in the internal simulationp process however it can be also called from 
+            outside.
+            
+            Raises:
+                EnsembleAPILoadLibraryError: When the library cannot be loaded
+        """
+
         try:
             lib_symuvia = cdll.LoadLibrary(self.libraryPath)
         except OSError:
@@ -437,6 +445,7 @@ class Simulator(Configurator, RuntimeDevice):
 
         for sensor, probablity in access_probability.items():
             self.__library.SymModifyControlZoneEx(-1, self.dctidzone[sensor], c_double(probablity))
+        self.__library.SymApplyControlZonesEx(-1)
         return self.dctidzone
 
     def __enter__(self) -> None:
@@ -472,7 +481,7 @@ class Simulator(Configurator, RuntimeDevice):
         """
         self.__dct_par = {
             "time_step": self.simulation.time_step,
-            "engine_tau": ct.ENGINE_CONSTANT,
+            "engine_tau": CT.ENGINE_CONSTANT,
         }
 
     # ============================================================================
